import request from '@/utils/request'
// 获取配置列表数据
export function getList(params) {
  return request({
    url: '/drill/configuration/list',
    method: "get",
    params
  });
}
// 获取年度演习计划列表数据
export function getYearList(params) {
  return request({
    url: '/drill/emergency/list',
    method: "get",
    params
  });
}
// 获取演习计划列表数据
export function getLists(params) {
  return request({
    url: '/drill/plan/list',
    method: "get",
    params
  });
}
// 获取演习部门
export function deptTree(params) {
  return request({
    url: '/system/user/deptTree',
    method: "get",
    params
  });
}
// 查看演习详情
export function getInfoItem(params) {
  return request({
    url: '/drill/plan/getInfo',
    method: "get",
    params
  });
}
// 查看演习图片
export function picList(params) {
  return request({
    url: '/drill/plan/picList',
    method: "get",
    params
  });
}
// 获取演习部门组织人
export function deptUser(params) {
  return request({
    url: `/system/user/allList?deptId=${params}`,
    method: "get"
  });
}
// 获取演习部门组织人
export function deptUsers() {
  return request({
    url: `/system/user/allList`,
    method: "get"
  });
}
// 通过id获取详情
export function getInfo(params) {
  return request({
    url: '/drill/configuration/getInfo',
    method: "get",
    params
  });
}
// 获取人员列表数据
export function getDeptUserTree(params) {
  return request({
    url: '/common/getDeptUserTree',
    method: "get",
    params
  });
}
// 演习完成都统计
export function statistics(params) {
  return request({
    url: '/drill/plan/statistics',
    method: "get",
    params
  });
}
// 查询演习总览
export function overviewList(params) {
  return request({
    url: '/drill/plan/overviewList',
    method: "get",
    params
  });
}
// 查询演习种类配置列表
export function allList(params) {
  return request({
    url: '/drill/emergency/allTypeList',
    method: "get",
    params
  });
}
// 新增演习配置
export function configuration(data) {
  return request({
    url: '/drill/configuration',
    method: "post",
    data
  });
}
// 演习总结编辑确认
export function summary(data) {
  return request({
    url: '/drill/plan/summary',
    method: "post",
    data
  });
}
// 演习总结编辑确认
export function process1(data) {
  return request({
    url: '/drill/plan/process',
    method: "post",
    data
  });
}
// 新增演习计划
export function plan(data) {
  return request({
    url: '/drill/plan',
    method: "post",
    data
  });
}
// 导入年度演戏计划
export function emergency(data) {
  return request({
    url: '/drill/emergency',
    method: "post",
    data
  });
}
// 编辑演习配置
export function configurations(data) {
  return request({
    url: '/drill/configuration',
    method: "put",
    data
  });
}
// 删除演习种类配置
export function remove(data) {
  return request({
    url: `/drill/configuration/remove?ids=${data}`,
    method: "delete"
  });
}
// 删除年度演习计划
export function removeYear(data) {
  return request({
    url: `/drill/emergency/remove?ids=${data}`,
    method: "delete"
  });
}
// 删除演习计划
export function removeDrill(data) {
  return request({
    url: `/drill/plan/remove?ids=${data}`,
    method: "delete"
  });
}
// 查询演习队伍列表
export function getTeamList(params) {
  return request({
    url: '/drill/contingent/list',
    method: "get",
    params
  });
}
// 删除演习队伍
export function removeTeam(data) {
  return request({
    url: `/drill/contingent/remove?ids=${data}`,
    method: "delete"
  });
}
// 新增演习队伍
export function addTeam(data) {
  return request({
    url: '/drill/contingent',
    method: "post",
    data
  });
}
// 编辑演习队伍
export function editTeam(data) {
  return request({
    url: '/drill/contingent',
    method: "put",
    data
  });
}
// 查询组织架构列表
export function getTree(params) {
  return request({
    url: '/drill/organizational/getTree',
    method: "get",
    params
  });
}
// 新增组织架构
export function addOrganizational(data) {
  return request({
    url: '/drill/organizational',
    method: "post",
    data
  });
}
// 编辑组织架构
export function editOrganizational(data) {
  return request({
    url: '/drill/organizational',
    method: "put",
    data
  });
}
// 删除组织架构
export function removeOrganizational(data) {
  return request({
    url: `/drill/organizational/remove?id=${data}`,
    method: "delete"
  });
}
